==> cronapp-framework-java-2.4.0.jar: cronapp/framework/authentication/social/SocialConfig.java <==
package cronapp.framework.authentication.social;

import cronapi.util.Operations;
import cronapp.framework.api.EventsManager;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;
import org.springframework.lang.Nullable;
import org.springframework.social.UserIdSource;
import org.springframework.social.config.annotation.ConnectionFactoryConfigurer;
import org.springframework.social.config.annotation.EnableSocial;
import org.springframework.social.config.annotation.SocialConfigurer;
import org.springframework.social.connect.ConnectionFactoryLocator;
import org.springframework.social.connect.UsersConnectionRepository;
import org.springframework.social.connect.mem.InMemoryUsersConnectionRepository;
import org.springframework.social.connect.web.ProviderSignInController;
import org.springframework.social.connect.web.SessionUserIdSource;
import org.springframework.social.facebook.connect.FacebookConnectionFactory;
import org.springframework.social.github.connect.GitHubConnectionFactory;
import org.springframework.social.google.connect.GoogleConnectionFactory;
import org.springframework.social.linkedin.connect.LinkedInConnectionFactory;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Properties;

@Configuration
@EnableSocial
public class SocialConfig implements SocialConfigurer {
  
  private SocialSignInAdapter socialSignInAdapter;
  
  private SocialConnectionSignup socialConnectionSignup;

  public SocialConfig(@Nullable SocialSignInAdapter socialSignInAdapter,
                      @Nullable SocialConnectionSignup socialConnectionSignup) {
    this.socialSignInAdapter = socialSignInAdapter;
    this.socialConnectionSignup = socialConnectionSignup;
  }

  private static Properties PROPERTIES;

  static {
    PROPERTIES = loadProperties();
  }
  
  private static Properties loadProperties() {
    ClassLoader classLoader = EventsManager.class.getClassLoader();
    try (InputStream stream = classLoader.getResourceAsStream("social.properties")) {
      try (InputStreamReader reader = new InputStreamReader(stream)) {
        Properties properties = new Properties();
        properties.load(reader);
        return properties;
      }
    }
    catch(Exception e) {
      // Abafa
    }
    return new Properties();
  }
  
  private static Properties getProperties() {
    if(Operations.IS_DEBUG) {
      return loadProperties();
    }
    else {
      return PROPERTIES;
    }
  }
  
  static boolean isEnabled(String key) {
    return "true".equals(getProperties().getProperty(key));
  }

  public static boolean isAutoSignUp() {
    return "true".equals(getProperties().getProperty("autoSignUp"));
  }
  
  @Override
  public void addConnectionFactories(ConnectionFactoryConfigurer connectionFactoryConfigurer, Environment environment) {
    if(isEnabled("facebook")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new FacebookConnectionFactory(
                getProperties().getProperty("facebook.appId"), getProperties().getProperty("facebook.appSecret")));
      }
      catch(Exception e) {
        // Abafa
      }
    }
    if(isEnabled("github")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new GitHubConnectionFactory(
                getProperties().getProperty("github.appId"), getProperties().getProperty("github.appSecret")));
      }
      catch(Exception e) {
        // Abafa
      }
    }
    if(isEnabled("linkedin")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new LinkedInConnectionFactory(
                getProperties().getProperty("linkedin.appId"), getProperties().getProperty("linkedin.appSecret")));
      }
      catch(Exception e) {
        // Abafa
      }
    }
    if(isEnabled("google")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new GoogleConnectionFactory(
                getProperties().getProperty("google.appId"), getProperties().getProperty("google.appSecret")));
      }
      catch(Exception e) {
        // Abafa
      }
    }
  }

  @Override
  public UserIdSource getUserIdSource() {
    return new SessionUserIdSource();
  }

  @Bean
  public ProviderSignInController providerSignInController(ConnectionFactoryLocator connectionFactoryLocator,
                                                           UsersConnectionRepository usersConnectionRepository) {
    ((InMemoryUsersConnectionRepository)usersConnectionRepository).setConnectionSignUp(socialConnectionSignup);

    return new ProviderSignInController(connectionFactoryLocator, usersConnectionRepository, socialSignInAdapter);
  }
  
  @Override
  public UsersConnectionRepository getUsersConnectionRepository(ConnectionFactoryLocator connectionFactoryLocator) {
    return new InMemoryUsersConnectionRepository(connectionFactoryLocator);
  }
  
}

==> cronapp-framework-java-2.6.1.jar: cronapp/framework/authentication/social/SocialConfig.java <==
package cronapp.framework.authentication.social;

import cronapi.util.Operations;
import cronapp.framework.api.EventsManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;
import org.springframework.lang.Nullable;
import org.springframework.social.UserIdSource;
import org.springframework.social.config.annotation.ConnectionFactoryConfigurer;
import org.springframework.social.config.annotation.EnableSocial;
import org.springframework.social.config.annotation.SocialConfigurer;
import org.springframework.social.connect.ConnectionFactoryLocator;
import org.springframework.social.connect.UsersConnectionRepository;
import org.springframework.social.connect.mem.InMemoryUsersConnectionRepository;
import org.springframework.social.connect.web.ProviderSignInController;
import org.springframework.social.connect.web.SessionUserIdSource;
import org.springframework.social.facebook.connect.FacebookConnectionFactory;
import org.springframework.social.github.connect.GitHubConnectionFactory;
import org.springframework.social.google.connect.GoogleConnectionFactory;
import org.springframework.social.linkedin.connect.LinkedInConnectionFactory;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Properties;

@Configuration
@EnableSocial
public class SocialConfig implements SocialConfigurer {

  private static final Logger logger = LoggerFactory.getLogger(SocialConfig.class);

  private SocialSignInAdapter socialSignInAdapter;

  private SocialConnectionSignup socialConnectionSignup;

  public SocialConfig(@Nullable SocialSignInAdapter socialSignInAdapter,
                      @Nullable SocialConnectionSignup socialConnectionSignup) {
    this.socialSignInAdapter = socialSignInAdapter;
    this.socialConnectionSignup = socialConnectionSignup;
  }

  private static Properties PROPERTIES;

  static {
    PROPERTIES = loadProperties();
  }

  private static Properties loadProperties() {
    ClassLoader classLoader = EventsManager.class.getClassLoader();
    try (InputStream stream = classLoader.getResourceAsStream("social.properties")) {
      try (InputStreamReader reader = new InputStreamReader(stream)) {
        Properties properties = new Properties();
        properties.load(reader);
        return properties;
      }
    } catch (Exception e) {
      logger.error("The \"social.properties\" file could not be loaded.", e);
    }
    return new Properties();
  }

  private static Properties getProperties() {
    if (Operations.IS_DEBUG) {
      return loadProperties();
    } else {
      return PROPERTIES;
    }
  }

  static boolean isEnabled(String key) {
    return "true".equals(getProperties().getProperty(key));
  }

  public static boolean isAutoSignUp() {
    return "true".equals(getProperties().getProperty("autoSignUp"));
  }

  @Override
  public void addConnectionFactories(ConnectionFactoryConfigurer connectionFactoryConfigurer, Environment environment) {
    if (isEnabled("facebook")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new FacebookConnectionFactory(
            getProperties().getProperty("facebook.appId"), getProperties().getProperty("facebook.appSecret")));
      } catch (Exception e) {
        logger.error("Could not build the FacebookConnectionFactory.", e);
      }
    }
    if (isEnabled("github")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new GitHubConnectionFactory(
            getProperties().getProperty("github.appId"), getProperties().getProperty("github.appSecret")));
      } catch (Exception e) {
        logger.error("Could not build the GitHubConnectionFactory.", e);
      }
    }
    if (isEnabled("linkedin")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new LinkedInConnectionFactory(
            getProperties().getProperty("linkedin.appId"), getProperties().getProperty("linkedin.appSecret")));
      } catch (Exception e) {
        logger.error("Could not build the LinkedInConnectionFactory.", e);
      }
    }
    if (isEnabled("google")) {
      try {
        connectionFactoryConfigurer.addConnectionFactory(new GoogleConnectionFactory(
            getProperties().getProperty("google.appId"), getProperties().getProperty("google.appSecret")));
      } catch (Exception e) {
        logger.error("Could not build the GoogleConnectionFactory.", e);
      }
    }
  }

  @Override
  public UserIdSource getUserIdSource() {
    return new SessionUserIdSource();
  }

  @Bean
  public ProviderSignInController providerSignInController(ConnectionFactoryLocator connectionFactoryLocator,
                                                           UsersConnectionRepository usersConnectionRepository) {
    ((InMemoryUsersConnectionRepository) usersConnectionRepository).setConnectionSignUp(socialConnectionSignup);

    return new ProviderSignInController(connectionFactoryLocator, usersConnectionRepository, socialSignInAdapter);
  }

  @Override
  public UsersConnectionRepository getUsersConnectionRepository(ConnectionFactoryLocator connectionFactoryLocator) {
    return new InMemoryUsersConnectionRepository(connectionFactoryLocator);
  }

}
